==> haskell-src-exts-util-0.2.5-19-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-src-exts-util.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: haskell-src-exts-util
version: 0.2.5
id: haskell-src-exts-util-0.2.5-2aWyWge1pbfFLBEIyogWHf
key: haskell-src-exts-util-0.2.5-2aWyWge1pbfFLBEIyogWHf
license: BSD-3-Clause
copyright: All Rights Reserved
maintainer: pepeiborra@gmail.com
author: Neil Mitchell, Jose Iborra
homepage: https://github.com/pepeiborra/haskell-src-exts-util
synopsis: Helper functions for working with haskell-src-exts trees
description:
    Helper functions for working with haskell-src-exts trees.
category: language
abi: 250ec66be87028df9b6cd9840e3427b3
exposed: True
exposed-modules:
    Language.Haskell.Exts.Util
hidden-modules: Language.Haskell.Exts.Bracket
                Language.Haskell.Exts.FreeVars Language.Haskell.Exts.Util.Internal
                Paths_haskell_src_exts_util
import-dirs: /usr/lib/ghc-8.6.5/site-local/haskell-src-exts-util-0.2.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/haskell-src-exts-util-0.2.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/haskell-src-exts-util-0.2.5
hs-libraries: HShaskell-src-exts-util-0.2.5-2aWyWge1pbfFLBEIyogWHf
depends:
    base-4.12.0.0 containers-0.6.0.1
    data-default-0.7.1.1-5JZ15VDIkjR94TfgciXLrQ
    haskell-src-exts-1.21.1-Gvt9SHsLQpU56VysZS6eS3 transformers-0.5.6.2
    uniplate-1.6.12-BTaZBg5AycHDY52rt8gZNP
haddock-interfaces: /usr/share/doc/haskell-src-exts-util/html/haskell-src-exts-util.haddock
haddock-html: /usr/share/doc/haskell-src-exts-util/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-src-exts-util-0.2.5-20-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-src-exts-util.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: haskell-src-exts-util
version: 0.2.5
id: haskell-src-exts-util-0.2.5-LvjQiGvKsL95gd5GulRwGX
key: haskell-src-exts-util-0.2.5-LvjQiGvKsL95gd5GulRwGX
license: BSD-3-Clause
copyright: All Rights Reserved
maintainer: pepeiborra@gmail.com
author: Neil Mitchell, Jose Iborra
homepage: https://github.com/pepeiborra/haskell-src-exts-util
synopsis: Helper functions for working with haskell-src-exts trees
description:
    Helper functions for working with haskell-src-exts trees.
category: language
abi: 1815d2ae77ffd8da98fbdfb2bf616542
exposed: True
exposed-modules:
    Language.Haskell.Exts.Util
hidden-modules: Language.Haskell.Exts.Bracket
                Language.Haskell.Exts.FreeVars Language.Haskell.Exts.Util.Internal
                Paths_haskell_src_exts_util
import-dirs: /usr/lib/ghc-8.6.5/site-local/haskell-src-exts-util-0.2.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/haskell-src-exts-util-0.2.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/haskell-src-exts-util-0.2.5
hs-libraries: HShaskell-src-exts-util-0.2.5-LvjQiGvKsL95gd5GulRwGX
depends:
    base-4.12.0.0 containers-0.6.0.1
    data-default-0.7.1.1-5JZ15VDIkjR94TfgciXLrQ
    haskell-src-exts-1.21.1-Gvt9SHsLQpU56VysZS6eS3 transformers-0.5.6.2
    uniplate-1.6.12-JIum57FWZN32cBPgiAnLvS
haddock-interfaces: /usr/share/doc/haskell-src-exts-util/html/haskell-src-exts-util.haddock
haddock-html: /usr/share/doc/haskell-src-exts-util/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
